<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Optimering och komprimering',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Vill du aktivera komprimering av  Javascript filer?' # MODIF
);

?>
